import { Injectable } from '@angular/core';
import {ElectronService} from "../core/services";
import {GameModel} from "./game-model/GameModel";
import {StoredGameModel} from "../../../app/storage/StoredGameModel";
import {ScriptAccount} from "./game-model/scriptAccounts/ScriptAccount";
import {ModelComponentType} from "./game-model/ModelComponentType";
import {ScriptAccountParser} from "./parser/ScriptAccountParser";
import {GamesystemParser} from "./parser/gamesystemParser/GamesystemParser";
import {Gamesystem} from "./game-model/gamesystems/Gamesystem";

@Injectable({
  providedIn: 'root'
})
export class ProjectService {

  gameModel: GameModel = new GameModel("New GameModel")
  constructor(private electronService: ElectronService) {
    if(electronService.isElectron) {
      electronService.ipcRenderer.on('get-project-data', (event: any, message: string) => {
        this.saveProject();
      })

      electronService.ipcRenderer.on('open-project', (event: any, loadedProject: StoredGameModel) => {
        this.loadProject(loadedProject);
      })
    }
  }

  saveProject() {

  }

  loadProject(storedGameModel: StoredGameModel) {
    const gameModel = new GameModel(storedGameModel.gameModelName)
    const gamesystemParser = new GamesystemParser();
    storedGameModel.loadedModels.forEach(storedComponent => {
      switch (storedComponent.componentType) {
        case ModelComponentType.SCRIPTACCOUNT: {
          const scriptAccount = ScriptAccountParser.parseScriptAccount(storedComponent);
          gameModel.addScriptAccount(scriptAccount);
        } break
        case ModelComponentType.GAMESYTEM: {
          gamesystemParser.parseGamesystem(storedComponent);
        }
      }
    })

    gamesystemParser.computeGamesystemStructure().forEach(topGamesystem => {
      gameModel.addGamesystem(topGamesystem)
    })

    console.log(gameModel)
    this.gameModel = gameModel;
  }


}
